#!/usr/bin/env bash
#
# This file is generated by l2tdevtools update-dependencies.py any dependency
# related changes should be made in dependencies.ini.

# Exit on error.
set -e

sudo add-apt-repository ppa:gift/dev -y
sudo apt-get update -qq
# Ubuntu 20.04 comes with python 3.8, we only support >= 3.9
sudo apt-get install -y python3-pip
sudo apt-get install --reinstall python3-apt
python3 --version
/usr/bin/python3 -m pip install poetry


if [[ "$*" =~ "include-docker" ]]; then
    echo "Adding docker key"
    curl -fsSL https://download.docker.com/linux/ubuntu/gpg | sudo apt-key add -
    sudo add-apt-repository \
       "deb [arch=amd64] https://download.docker.com/linux/ubuntu \
       $(lsb_release -cs) \
       stable"
    echo "apt update and install docker-ce"
    sudo apt-get update -qq
    sudo apt-get install -qq -y docker-ce
    curl -L https://github.com/docker/compose/releases/download/1.26.1/docker-compose-$(uname -s)-$(uname -m) -o docker-compose
    sudo cp docker-compose /usr/local/bin/docker-compose
    sudo chmod +x /usr/local/bin/docker-compose
fi

if [[ "$*" =~ "include-grr" ]]; then
    # Start the GRR server container.
    echo "Running include-grr"
    mkdir ~/grr-docker
    echo "Running the GRR docker container"
    sudo docker run \
      --name grr-server -v ~/grr-docker/db:/var/grr-datastore \
      -v ~/grr-docker/logs:/var/log \
      -e EXTERNAL_HOSTNAME="localhost" \
      -e ADMIN_PASSWORD="admin" \
      --ulimit nofile=1048576:1048576 \
      -p 127.0.0.1:8000:8000 -p 127.0.0.1:8080:8080 \
      -d grrdocker/grr:release grr

    echo "Sleeping 180 seconds"
    # Wait for GRR to initialize.
    /bin/sleep 180

    # Install the client.
    echo "Installing GRR client on $NODE_NAME"
    sudo docker cp grr-server:/usr/share/grr-server/executables/installers .
    if sudo dpkg -i installers/*amd64.deb; then
        echo "GRR client installed successfully"
    else
        echo "GRR client installation failed"
        exit 1
    fi
fi

if [[ "$*" =~ "include-timesketch" ]]; then
    # Start the Timesketch server container.
    export PLASO_PPA_TRACK="stable"
    export OPENSEARCH_VERSION="2.9.0"
    echo "Cloning Timesketch from Github"
    git clone https://github.com/google/timesketch.git
    cd timesketch
    cd docker
    cd e2e
    echo "Running the Timesketch docker-compose script"
    sudo -E docker-compose up -d
    # Wait for Timesketch to initialize
    echo "Sleeping 300 seconds..."
    /bin/sleep 300
    cd ../../..
    echo "Credentials for e2e tests are set in https://github.com/google/timesketch/blob/master/docker/e2e/docker-compose.yml"
fi

if [[ "$*" =~ "include-plaso" ]]; then
    echo "Installing plaso"
    docker pull log2timeline/plaso:latest
fi

# pending resolution of https://github.com/log2timeline/l2tdevtools/issues/595
if [[ "$*" =~ "include-turbinia" ]]; then
    echo "Installing Turbinia"
    /usr/bin/python3 -m pip install turbinia
fi

echo "Installing dftimewolf requirements via Poetry"
# Install dftimewolf's pinned requirements
poetry install
